package com.displaynone.acss.components.acs;

import com.displaynone.acss.components.acs.code.CodeModel;
import com.displaynone.acss.components.acs.code.service.CodeService;
import com.displaynone.acss.components.acs.visit.VisitModel;
import com.displaynone.acss.components.acs.visit.service.VisitService;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Optional;

@Component
@RequiredArgsConstructor
public class ACSComponent {
    private final CodeService codeService;
    private final VisitService visitService;

    public Optional<CodeModel> getCodeById(Long codeId) {
        return codeService.getCodeById(codeId);
    }

    public CodeModel getCodeByIdStrict(Long codeId) {
        return codeService.getCodeByIdStrict(codeId);
    }

    public Optional<CodeModel> getCodeByValue(Long value) {
        return codeService.getCodeByValue(value);
    }

    public CodeModel getCodeByValueStrict(Long value) {
        return codeService.getCodeByValueStrict(value);
    }

    public boolean isCodeIdValid(Long codeId) {
        return codeService.isValid(codeId);
    }

    public boolean isCodeValid(Long codeId) {
        return codeService.isCodeIdValid(codeId);
    }

    public List<VisitModel> getVisitsByCodeId(Long codeId) {
        return visitService.getByCodeId(codeId);
    }

    public List<VisitModel> getVisitsByUserId(Long userId) {
        return visitService.getByUserId(userId);
    }

    public Page<VisitModel> getVisitsByCodeIdPaginated(Long codeId, Pageable pageable) {
        return visitService.getVisitsByCodeIdPaginated(codeId, pageable);
    }

    public Page<VisitModel> getVisitsByUserIdPaginated(Long userId, Pageable pageable) {
        return visitService.getVisitsByUserIdPaginated(userId, pageable);
    }
}
