package com.displaynone.acss.components.acs.code.service;

import com.displaynone.acss.components.acs.code.CodeModel;
import com.displaynone.acss.components.acs.code.CodeRepository;
import com.displaynone.acss.exception.generics.NotFoundHTTPException;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

import java.util.Optional;


@Component
@RequiredArgsConstructor
public class CodeServiceImpl implements CodeService {
    private final CodeRepository codeRepository;

    @Override
    public Optional<CodeModel> getCodeById(Long codeId) {
        return codeRepository.findById(codeId);
    }

    @Override
    public CodeModel getCodeByIdStrict(Long codeId) {
        Optional<CodeModel> model = codeRepository.findById(codeId);
        if (model.isEmpty()) throw new NotFoundHTTPException("Code not found");
        return model.get();
    }

    @Override
    public Optional<CodeModel> getCodeByValue(Long value) {
        return codeRepository.findByCodeValue(value);
    }

    @Override
    public CodeModel getCodeByValueStrict(Long value) {
        Optional<CodeModel> model = getCodeByValue(value);
        if (model.isEmpty()) throw new NotFoundHTTPException("Code not found");
        return model.get();
    }

    @Override
    public boolean isCodeIdValid(Long codeID) {
        return getCodeById(codeID).isPresent();
    }

    @Override
    public boolean isValid(Long code) {
        return getCodeByValue(code).isPresent();
    }
}
