package com.displaynone.acss.controllers.acs;

import com.displaynone.acss.components.acs.ACSComponent;
import com.displaynone.acss.components.acs.visit.VisitDTO;
import com.displaynone.acss.components.acs.visit.VisitMapper;
import com.displaynone.acss.components.auth.AuthComponent;
import com.displaynone.acss.components.auth.models.user.UserModel;
import com.displaynone.acss.exception.generics.ForbiddenHTTPException;
import com.displaynone.acss.exception.generics.NotFoundHTTPException;
import lombok.RequiredArgsConstructor;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;


@RestController
@RequestMapping("/api/acs")
@RequiredArgsConstructor
public class ACSController {
    private final ACSComponent acsComponent;
    private final AuthComponent authComponent;

    @PostMapping("/open")
    public ResponseEntity<Void> open(@RequestBody OpenRQB body) {
        Long code = body.getCode();
        if (!acsComponent.isCodeValid(code)) throw new ForbiddenHTTPException("Invalid code");
        return ResponseEntity.ok(null);
    }

    @GetMapping("visits/me")
    public ResponseEntity<Page<VisitDTO>> getMyVisitsPaginated(
            @RequestParam(defaultValue = "0") int page,
            @RequestParam(defaultValue = "10") int size
    ) {
        Pageable pageable = PageRequest.of(page, size);
        UserModel user = (UserModel) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
        return ResponseEntity.ok(acsComponent.getVisitsByUserIdPaginated(user.getId(), pageable).map(VisitMapper::convertToDTO));
    }

    @GetMapping("visits/login/{login}")
    public ResponseEntity<Page<VisitDTO>> getUserVisitsPaginated(
            @RequestParam(defaultValue = "0") int page,
            @RequestParam(defaultValue = "10") int size,
            @PathVariable String login
    ) {
        Pageable pageable = PageRequest.of(page, size);
        UserModel user = authComponent.getUserByLoginStrict(login);
        return ResponseEntity.ok(acsComponent.getVisitsByUserIdPaginated(user.getId(), pageable).map(VisitMapper::convertToDTO));
    }

    @GetMapping("visits/code/{codeId}")
    public ResponseEntity<Page<VisitDTO>> getUserVisitsPaginated(
            @RequestParam(defaultValue = "0") int page,
            @RequestParam(defaultValue = "10") int size,
            @PathVariable Long codeId
    ) {
        Pageable pageable = PageRequest.of(page, size);
        if (!acsComponent.isCodeIdValid(codeId)) throw new NotFoundHTTPException("Invalid code id");
        return ResponseEntity.ok(acsComponent.getVisitsByCodeIdPaginated(codeId, pageable).map(VisitMapper::convertToDTO));
    }
}
